@@ -9,20 +9,21 @@ import matplotlib
 from sklearn.decomposition import PCA
 from sklearn.cross_decomposition import PLSRegression
 from . import pre
-from ..dr import lda
+from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
 
 from ..vis import *
 DATA_FOLDER = os.path.dirname(os.path.dirname(
     os.path.realpath(__file__))) + "/data/"
 
-DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False, '7341_C1 desc.txt', ['Stage 4 (4-7 years) formula'],200),
-               's3_formula': ('B3.csv', ',', False, 'B3 desc.txt', ['Stage 3 (12~36 months) infant formula'],200),
+# path, delimiter, has_y, path_desc, labels, default_shift
+DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False, '7341_C1 desc.txt', ['Stage 4 (4-7 years) formula'], 200),
+               's3_formula': ('B3.csv', ',', False, 'B3 desc.txt', ['Stage 3 (12~36 months) infant formula'], 200),
                's4_formula_c2': ('7341_C2.csv', ',', True, '7341_C2 desc.txt', ['Brand 1', 'Brand 2'], 1000),
                's4_formula_c3': ('7341.csv', ',', True, '7341 desc.txt', ['Brand 1', 'Brand 2', 'Brand 3'], 1000),
                'milk_tablet_candy': ('734b.csv', ',', False, '734b desc.txt', ['Compressed Milk Tablet Candy'], 200),
                'yogurt': ('7346.csv', ',', True, '7346 desc.txt', ["YL", "GM", "WQ", "MN"], 200),
-               'vintage': ('7344.txt', '\t', False, '7344 desc.txt', ['8-year vintage'],200),
-               'vintage_spi': ('7345.csv', ',', True, '7345 desc.txt', ["5Y", "8Y", "16Y", "26Y"],200),
+               'vintage': ('7344.txt', '\t', False, '7344 desc.txt', ['8-year vintage'], 200),
+               'vintage_spi': ('7345.csv', ',', True, '7345 desc.txt', ["5Y", "8Y", "16Y", "26Y"], 200),
                'vintage_526': ('7344_Y5Y26.csv', ',', True, '7344_Y5Y26 desc.txt', ["5Y", "26Y"], 2000),
                'beimu': ('754a_C2S_Beimu.txt', ',', True, '754a_C2S_Beimu desc.txt', ["Sichuan", "Zhejiang"], 300),
                'shihu_c2': ('754b_C2S_Shihu.csv', ',', True, '754b_C2S_Shihu desc.txt', ['Yunnan', 'Zhejiang'], 500),
@@ -33,7 +34,9 @@ DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False, '7341_C1 desc.txt', ['S
                'cheese': ('Cheese_RAMAN.csv', ',', True, 'Cheese_RAMAN desc.txt', ['MK', 'SL', 'YL'], 200),
                'huangjing': ('7a43.csv', ',', True, '7a43 desc.txt', ['Wild', 'Cultivated'], 3000),
                'huangjing2': ('7a47.csv', ',', True, '7a47 desc.txt', ['Red-Stem', 'Green-Stem'], 3000),
-               'chaihu_rm': ('7a41.csv', ',', True, '7a41 desc.txt', ['Wild', 'Cultivated', 'B. smithii Wolff', 'Gansu', 'Shanxi', 'vinegar Concocted', 'Terrestrosin D'], 1500),
+               'chaihu_rm': ('7a41.csv', ',', True, '7a41 desc.txt', ['Neimeng Wild', 'Neimeng Cultivated', 'Neimeng Black Bupleurum', 'Gansu', 'Shanxi', 'vinegar Concocted', 'Saikosaponin'], 1500),
+               'chaihu_hplc': ('7a41_hplc.xlsx', 'n/a', True, '7a41_hplc desc.txt', [ 'Shanxi', 'Gansu', 'Neimeng Wild', 'Neimeng Cultivated', 'Neimeng Black Bupleurum', 'Saikosaponin 5ppm', 'Saikosaponin 10ppm', 'Saikosaponin 20ppm', 'Saikosaponin 40ppm'], 1),
+               'chaihu_ms': ('7b43.csv', ',', True, '7b43 desc.txt', ["wild", "cultivated"], 200),
                'rice_cereal': ('7741_rice_cereal_rm.csv', ',', True, '7741_rice_cereal_rm desc.txt', ['LF', 'EB'], 3000),
                'organic_milk': ('MALDITOFMS_ORGANICMILK_7047_C02.csv', ',', True, 'MALDITOFMS_ORGANICMILK_7047_C02 desc.txt', ['inorganic', 'organic'], 1000),
                'milkpowder_enose': ('7747.pkl', ',', True, '7747 desc.txt', ['cn', 'au'], 200),
@@ -44,8 +47,7 @@ DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False, '7341_C1 desc.txt', ['S
                'yimi_rm': ('yimi_raman.csv', ',', False, 'yimi_raman desc.txt', ['coix seed'], 200),
                'hangbaiju_rm': ('hangbaiju_raman.csv', ',', False, 'hangbaiju_raman desc.txt', ['chrysanthemum morifolium'], 200),
                'salt': ('7545.csv', ',', True, '7545 desc.txt', ["well salt", "sea salt"], 200),
-               'chaihu_ms': ('7b43.csv', ',', True, '7b43 desc.txt', ["wild", "cultivated"], 200),
-               'mouse_omics': ('metabolomics.txt', '\t', True, 'metabolomics desc.txt', ["control", "experiment"], 50000000)             
+               'mouse_omics': ('metabolomics.txt', '\t', True, 'metabolomics desc.txt', ["control", "experiment"], 50000000)
                }
 
 
@@ -98,11 +100,11 @@ def load_dataset(id, SD=1, shift=None, x_range=None, y_subset=None, display=True
 
     else:
         desc = ''
-    
+
     return X, y, X_names, desc, labels
 
 
-def open_dataset(path, delimiter=',', has_y=True, labels = None, x_range=None, y_subset=None):
+def open_dataset(path, delimiter=',', has_y=True, labels=None, x_range=None, y_subset=None):
     '''
     Parameters
     ----------
@@ -115,16 +117,23 @@ def open_dataset(path, delimiter=',', has_y=True, labels = None, x_range=None, y
 
     # special treatment for specific datasets
     if 'metabolomics.txt' in path:
-        data = pd.read_csv(path, delimiter = '\t') # ,header=None
-        X_names_mol = data.iloc[:5022,4].values.tolist() # molecules
-        X = data.iloc[:5022,19:].T.values
-        y = np.array([0]*int(len(X)/2) + [1]*int(len(X)/2) )
-        X_names = list(map(float, data.iloc[:5022,1].values)) # m/z
+        data = pd.read_csv(path, delimiter='\t')  # ,header=None
+        _ = data.iloc[:5022, 4].values.tolist()  # molecules
+        X = data.iloc[:5022, 19:].T.values
+        y = np.array([0]*int(len(X)/2) + [1]*int(len(X)/2))
+        X_names = list(map(float, data.iloc[:5022, 1].values))  # m/z
 
-        idx = np.argsort(X_names) # re-order by m/z
+        idx = np.argsort(X_names)  # re-order by m/z
         X_names = np.array(X_names)[idx]
-        X = X[:,idx]  # re-arrange columns to match X_names
-
+        X = X[:, idx]  # re-arrange columns to match X_names
+    
+    elif '7a41_hplc' in path:
+        df=pd.read_excel(path) # sheet 1
+        X_names = df.iloc[:,0].values.tolist()
+        labels = df.columns.values[1:].tolist()
+        y = np.array(range(len(labels)))
+        X = df.iloc[:,1:].values.T
+        
     elif ext == '.pkl':
 
         with open(path, 'rb') as f:
@@ -196,7 +205,7 @@ def open_dataset(path, delimiter=',', has_y=True, labels = None, x_range=None, y
     if cnt_nan > 0:
         print('Found' + str(cnt_nan) +
               'NaN elements in X. You may need to purge NaN.')
-    
+
     if labels is not None and labels != [] and y_subset is not None:
         labels = list(np.array(labels)[y_subset])
 
@@ -212,29 +221,40 @@ def scatter_plot(X, y, labels=None, tags=None):
 
     pca = PCA(n_components=2)  # keep the first 2 components
     X_pca = pca.fit_transform(X)
-    plotComponents2D(X_pca, y, legends=labels, tags=tags)
+    plot_components_2d(X_pca, y, legends=labels, tags=tags)
     plt.title('PCA')
     plt.show()
 
     # for very-high dimensional data, lda/pls is very slow.
     if y is not None and X.shape[1] < 6000:
-
-        X_lda = lda(X, y)
-        # , tags = range(len(y)), ax = ax
-        plotComponents2D(X_lda, y, legends=labels)
-        plt.title('LDA`')
+        
+        '''
+        lda = LinearDiscriminantAnalysis()
+        X_lda = lda.fit(X, y).transform(X)
+        if X_lda.shape[1] == 1:
+            plot_components_1d(X_lda, y, legends=labels)
+            plt.title('LDA\nX has only 1 FEATURE/COLUMN. Plot X directly.')   
+        else:
+            plot_components_2d(X_lda, y, legends=labels)
+            plt.title('LDA')
         plt.show()
+        '''
 
         pls = PLSRegression(n_components=2, scale=False)
         X_pls = pls.fit(X, y).transform(X)
         # , tags = range(len(y)), ax = ax
-        plotComponents2D(X_pls, y, legends=labels)
+        plot_components_2d(X_pls, y, legends=labels)
         # print('score = ', np.round(pls.score(X, y),3))
         plt.title('PLS')
         plt.show()
 
 
 def draw_average(X, X_names, SD=1):
+    '''
+    X: 2D array, each row is a spectrum
+    X_names: 1D array, the x-axis labels
+    SD: standard deviation, 0 will not use the error bar
+    '''
 
     matplotlib.rcParams.update({'font.size': 16})
 
@@ -342,8 +362,7 @@ def draw_class_average(X, y, X_names, labels=None, SD=1, shift=200):
                         s=1
                         )
 
-        plt.legend()
-
+    plt.legend()
     plt.title(u'Averaged Spectrums for Each Category\n')
     # plt.xlabel(r'$ cm^{-1} $') # depending on it is Raman or MS
     plt.ylabel('Intensity')
@@ -353,6 +372,45 @@ def draw_class_average(X, y, X_names, labels=None, SD=1, shift=200):
     matplotlib.rcParams.update({'font.size': 10})
 
 
+def draw_class_average_3d(X, y, X_names, labels=None, view_point = (30,-50)):
+    '''
+    Draw the average spectrum of each class in a 3D plot.
+
+    Parameter
+    ---------
+    view_point : tuple, the view point of the 3D plot.
+    '''
+
+    matplotlib.rcParams.update({'font.size': 15, 'font.family': 'Times New Roman', 'figure.dpi': 400})
+    
+    fig = plt.figure(figsize=(24, 10))
+
+    if labels is None:
+        labels = list(map(lambda s: 'Class ' + str(s), set(y)))
+
+        
+    ax = fig.add_subplot(111,projection='3d')
+    
+    for c, label in zip(set(y), labels):
+        Xc = X[y == c]
+        yc = y[y == c]
+        # ax.scatter(X_names, [c]*len(X_names), np.mean(Xc, axis=0), label=label, s = 1)
+        ax.plot(X_names, [c]*len(X_names), np.mean(Xc, axis=0), label=label)
+        
+
+    ax.view_init(view_point[0], view_point[1])
+    ax.set_zlabel('Intensity')
+    plt.legend()
+    plt.title('Averaged Spectrums for Each Category\n')
+    plt.xlabel('Features') # depending on it is Raman or MS
+    plt.ylabel('Category')
+    plt.yticks( range(len(set(y))) )
+    plt.ylim([-0.5, len(set(y))-0.5])
+    # plt.grid(False)
+    plt.show()
+
+    matplotlib.rcParams.update({'font.size': 10, 'font.family': 'sans-serif', 'figure.dpi': 100})
+
 def peek_dataset(path,  delimiter=',', has_y=True, labels=None, SD=1, shift=200, x_range=None, y_subset=None):
 
     X, y, X_names, labels = open_dataset(
