@@ -1,6 +1,4 @@
-from .plotComponents1D import *
-from .plotComponents2D import *
-from .plotComponents3D import *
+from .plot_components import *
 from .feature_importance import *
 from .unsupervised_dimension_reductions import *
 from .supervised_dimension_reductions import *
\ No newline at end of file
